/* this file needs to be converted to DTML */

.newsImage.nitf
{
    cursor: pointer;
}

.portaltype-collective-nitf-content .newsImageContainer
{
    position: relative;
}

.portaltype-collective-nitf-content .newsImageContainer  .magnify
{
    position: absolute;
    top: 5px;
    right: 5px;

    display: block;

    width: 13px;
    height: 13px;

    background: transparent url(++resource++collective.nitf/images/search-ico.png) no-repeat;
}

/* used in media_sorter.pt */
.sortable-media
{
    margin: 0 !important;
    padding: 0;

    list-style-type: none !important;
}

.sortable-media li
{
    position: relative;

    float: left;

    width: 128px;
    height: 128px;
    margin: 0 10px 10px 0;
    padding: 4px;

    border: 1px solid silver;
    background-color: #fff;
}
.sortable-media li:hover .button
{
    visibility: visible;
}
.sortable-media .draggable-item
{
    display: block;
    overflow: hidden;

    height: 90px;

    cursor: move;

    border: medium none;
}

.sortable-media .button,
.sortable-media .button:hover
{
    float: right;

    margin-top: 6px;
    padding: 3px 10px 3px 5px;

    color: #fff !important;
    background-color: #999;
}

.sortable-media .button
{
    right: 0;

    visibility: hidden;
}
.button .icon
{
    float: left;

    width: 13px;
    height: 15px;
}
.button.edit
{
    background: none repeat scroll 0 0 #75ad0a;
}
.button.edit .icon
{
    line-height: 50px;

    margin-top: 4px;
    margin-right: 5px;

    background: url(++resource++collective.nitf/images/icons-media.png) no-repeat scroll 0 top transparent;
}
.button.delete
{
    position: absolute;
    top: 0;
    right: 0;

    background-color: #c43c35;
}
.button.delete .icon
{
    line-height: 50px;

    margin-right: 5px;

    background: url(++resource++collective.nitf/images/icons-media.png) no-repeat scroll -15px top transparent;
}

/* Cycle2 Slideshow */
.slide.cycle-slide
{
    overflow: hidden;

    max-width: 100%;
}
.slide.cycle-slide > a
{
    line-height: 0;
}
/* Prev/Next arrows */
.cycle-prev,
.cycle-next
{
    position: absolute;
    z-index: 110;
    top: 0;

    width: 25%;
    height: 79%;

    cursor: pointer;

    opacity: .7;
    border: none;
}
.cycle-prev
{
    left: 0;

    background: url(++resource++collective.nitf/images/prev-arrow.png) no-repeat scroll 10% 50% rgba(0, 0, 0, 0);
}
.cycle-next
{
    right: 0;

    background: url(++resource++collective.nitf/images/next-arrow.png) no-repeat scroll 90% 50% rgba(0, 0, 0, 0);
}
.cycle-prev:hover,
.cycle-next:hover
{
    opacity: 1;
}
.cycle-carrossel .thumb-itens
{
    cursor: pointer;
}
a.edit-tile-link
{
    z-index: 150;
}
.cycle-pager-container
{
    position: absolute;
    z-index: 110;
    top: 0;

    width: 100%;

    text-align: center;
}
.cycle-pager
{
    display: inline-block;

    margin: 0 auto;
    padding: 8px;
}
.cycle-pager > span
{
    cursor: pointer;
}
.cycle-pager .cycle-pager-active
{
    opacity: 1;
}
.cycle-pager-container.thumbnails_square .cycle-pager
{
    background: white;
}
.cycle-pager-container.thumbnails_square .cycle-pager img
{
    margin-right: 8px;

    border-radius: 5px;
}
.cycle-pager-container.thumbnails_square .cycle-pager a:last-child img
{
    margin-right: 0;
}
.cycle-pager-container.numbers .cycle-pager
{
    opacity: .6;
    background-color: #222;
}
#content .cycle-pager-container.numbers a:link
{
    font-size: 1.25em;

    padding: 0 .25em;

    color: white;
}
.cycle-caption
{
    position: absolute;
    z-index: 120;
    top: 15px;
    right: 15px;

    color: white;
}
.cycle-overlay
{
    position: absolute;
    z-index: 120;
    bottom: 0;

    width: 100%;
    padding: 15px 0;

    opacity: .5;
    color: white;
    background: none repeat scroll 0 0 black;
}
.cycle-overlay > div
{
    padding: 0 15px;
}
/* Stop overlay being bigger than slides */
.slide.cycle-sentinel
{
    min-height: 6em;
}
.contentActions
{
    z-index: 130;
}
/* Hide Image position widget & Image visibility widget */
#formfield-covertile-cycle2-carousel-image .visibility-box,
#covertile-cycle2-carousel-image-imgsize + span,
#covertile-cycle2-carousel-image-position
{
    display: none;
}

.wrapper-slideshow
{
    float: left;

    min-width: 100%;
}

.cycle-slideshow .slide,
.cycle-slideshow .slide img
{
    min-width: 100%;
}
.cycle-slideshow
{
    max-width: 65%;
    margin: 0 auto;
}
.cycle-slideshow .cycle-slide img
{
    position: relative;
    top: 0;
    left: 0;

    display: block;

    padding: 0;
}

/* Stop Flash of unstyled content */
.cycle-slideshow .slide
{
    display: none;
}

/* Stops pagers being misplaced when multiple carousel tiles on page */
.tile
{
    position: relative;
}
